

### Updated Version of the CoTiMA R-script using

install.packages('devtools')
library(devtools)
install_github("CoTiMA/CoTiMA")
library('CoTiMA')


# Working directory to save results, & prefix for figure file names. Use "/" instead of "\".
activeDirectory <- "/Users/cdormann/SynologyDrive/Drive/CHRISTIAN/TEXTE/ARTIKEL/COTIMA/_UPDATE 2021/"
coresToUse = -1 ## !!!!!! SET THIS TO 1 INSTEAD OF -1 IF YOU ARE USING WINDOWS


### EXTRACT Primary Study Information from the Literature ###
delta_t1 <-6;
sampleSize1 <- 222
empcov1 <- matrix(c(
  1,	  0.11,	0.64,	0.14,
  0.11, 1,   	0.2,	0.69,
  0.64,	0.2,	1,	  0.21,
  0.14,	0.69,	0.21,	1), nrow=4, ncol=4)

delta_t2 <- 18
sampleSize2 <- 64
empcov2 <- matrix(c(
  1,	0.15,	0.53,	0.17,
  0.15,	1,	0.19,	0.57,
  0.53,	0.19,	1,	0.21,
  0.17,	0.57,	0.21,	1), nrow=4, ncol=4)

delta_t3 <-12
sampleSize3 <- 412
empcov3 <- matrix(c(
  1,	0.26,	0.66,	0.05,
  0.26,	1,	0.66,	0.21,
  0.66,	0.66,	1,	0.17,
  0.05,	0.21,	0.17,	1), nrow=4, ncol=4)

delta_t4 <-18
sampleSize4 <- 526
empcov4 <- matrix(c(
  1,	0.04,	0.61,	-0.02,
  0.04,	1,	0.06,	0.53,
  0.61,	0.06,	1,	0.06,
  -0.02,	0.53,	0.06,	1), nrow=4, ncol=4)

delta_t5 <-3.5
sampleSize5 <- 300
empcov5 <- matrix(c(
  1,	0.06,	0.56,	0.14,
  0.06,	1,	-0.02,	0.23,
  0.56,	-0.02,	1,	0.17,
  0.14,	0.23,	0.17,	1), nrow=4, ncol=4)

delta_t6 <- 11
sampleSize6 <- 59
empcov6 <- matrix(c(
  1,	-0.03,	0.45,	-0.08,
  -0.03,	1,	-0.06,	0.5,
  0.45,	-0.06,	1,	0.15,
  -0.08,	0.5,	0.15,	1), nrow=4, ncol=4)

delta_t7 <-12
sampleSize7 <- 35
empcov7 <- matrix(c(
  1,	0.2,	0.68,	0.21,
  0.2,	1,	0.24,	0.49,
  0.68,	0.24,	1,	0.21,
  0.21,	0.49,	0.21,	1), nrow=4, ncol=4)

delta_t8 <-3
sampleSize8 <- 128
empcov8 <- matrix(c(
  1,	0.09,	0.62,	0.09,
  0.09,	1,	0.09,	0.65,
  0.62,	0.09,	1,	0.05,
  0.09,	0.65,	0.05,	1), nrow=4, ncol=4)

delta_t9 <-12
sampleSize9 <- 200
empcov9 <- matrix(c(
  1,	0.19,	0.48,	0.11,
  0.19,	1,	0.08,	0.64,
  0.48,	0.08,	1,	0.08,
  0.11,	0.64,	0.08,	1),  nrow=4, ncol=4)

delta_t10 <-2
sampleSize10 <- 80
empcov10 <- matrix(c(
  1,	0.09,	0.73,	0.18,
  0.09,	1,	0.24,	0.44,
  0.73,	0.24,	1,	0.15,
  0.18,	0.44,	0.15,	1), nrow=4, ncol=4)

### PREPARE ###
studyList1 <- ctmaPrep(selectedStudies = c(1:10))

### INITial Fitting of each primary study separately (Heterogeneity Model) ###
# Table 3 (Heterogeneity Model)
coresToUse = -1    # SET THIS TO 1 INSTEAD OF -1 IF YOU ARE USING WINDOWS
CoTiMAInitFit1 <- ctmaInit(primaryStudies = studyList1,
                           n.latent = 2,
                           saveSingleStudyModelFit = c("Riketta", 1:10),
                           activeDirectory = activeDirectory,
                           coresToUse=coresToUse,
                           finishsamples = 10000, # accuracy of SE and CI estimates above normal (1000)
                           scaleTime = 1/12)      # faster new version of CoTiMA perform better if all lags < 7
saveRDS(CoTiMAInitFit1, paste0(activeDirectory, "CoTiMAInitFit1.rds"))
summary(CoTiMAInitFit1)

### BIAS ###
# Table 3 (I2 & Random Effects. Note: All results now refer to time-scaled (i.e., 1/12) effects)
CoTiMABiasFit1 <- ctmaBiG(CoTiMAInitFit1)
saveRDS(CoTiMABiasFit1, paste0(activeDirectory, "CoTiMABiasFit1.rds"))
summary(CoTiMABiasFit1)

### CoTiMA
# Table 3 (Multi Sample Homogeneity Model)
CoTiMAFullFit1 <- ctmaFit(CoTiMAInitFit1, coresToUse = coresToUse,
                          scaleTime=1/12) # scaleTime is not necessary here, but INIT+Full plots then use same scale
saveRDS(CoTiMAFullFit1, paste0(activeDirectory, "CoTiMAFullFit1.rds"))
summary(CoTiMAFullFit1)


# Figure 3
plot(ctmaFitList(CoTiMAInitFit1, CoTiMAFullFit1),
     timeUnit="Years",
     timeRange=c(0, 8, .1) ) # 0 to 8 years in steps of .1 (makes plots smoother than 1.0)


### CoTiMA
# Page 17, 1st para. (Note: time scaling is not necessary here because all subsequent models use the same)
CoTiMAFullInv23Fit1 <- ctmaFit(ctmaInitFit = CoTiMAInitFit1,
                                invariantDrift = c("V2toV1", "V1toV2"),
                                coresToUse = coresToUse)
saveRDS(CoTiMAFullInv23Fit1, file=paste0(activeDirectory, "CoTiMAFullInv23Fit1.rds"))

CoTiMAFullInvEq23Fit1 <- ctmaEqual(CoTiMAFullInv23Fit1,
                                   coresToUse = coresToUse)
saveRDS(CoTiMAFullInvEq23Fit1, file=paste0(activeDirectory, "CoTiMAFullInvEq23Fit1.rds"))
summary(CoTiMAFullInvEq23Fit1)
